==> freeplane_1.6.13.orig.tar.gz: freeplane-1.6.13/freeplane/src/main/java/org/freeplane/features/map/ToggleChildrenFoldedAction.java <==
/*
 *  Freeplane - mind map editor
 *  Copyright (C) 2008 Joerg Mueller, Daniel Polansky, Christian Foltin, Dimitry Polivaev
 *
 *  This file is modified by Dimitry Polivaev in 2008.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.freeplane.features.map;

import java.awt.event.ActionEvent;

import org.freeplane.core.ui.AFreeplaneAction;
import org.freeplane.features.mode.Controller;

/**
 * @author foltin
 */
class ToggleChildrenFoldedAction extends AFreeplaneAction {
	static final String NAME = "toggleChildrenFolded";
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	public ToggleChildrenFoldedAction() {
		super("ToggleChildrenFoldedAction");
	}

	public void actionPerformed(final ActionEvent e) {
		final Controller controller = Controller.getCurrentController();
		final IMapSelection mapSelection = controller.getSelection();
		final NodeModel model = mapSelection.getSelected();
		MapController mapController = Controller.getCurrentModeController().getMapController();
		mapController.toggleFolded(mapController.childrenUnfolded(model));
		mapSelection.selectAsTheOnlyOneSelected(model);
	}
}

==> freeplane_1.7.10.orig.tar.gz: freeplane-1.7.10/freeplane/src/main/java/org/freeplane/features/map/ToggleChildrenFoldedAction.java <==
/*
 *  Freeplane - mind map editor
 *  Copyright (C) 2008 Joerg Mueller, Daniel Polansky, Christian Foltin, Dimitry Polivaev
 *
 *  This file is modified by Dimitry Polivaev in 2008.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.freeplane.features.map;

import java.awt.event.ActionEvent;

import org.freeplane.core.ui.AFreeplaneAction;
import org.freeplane.features.mode.Controller;

/**
 * @author foltin
 */
class ToggleChildrenFoldedAction extends AFreeplaneAction {
	static final String NAME = "toggleChildrenFolded";
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	public ToggleChildrenFoldedAction() {
		super("ToggleChildrenFoldedAction");
	}

	public void actionPerformed(final ActionEvent e) {
		final Controller controller = Controller.getCurrentController();
		final IMapSelection mapSelection = controller.getSelection();
		final NodeModel model = mapSelection.getSelected();
		MapController mapController = Controller.getCurrentModeController().getMapController();
		mapController.toggleFolded(model.getChildren());
		mapSelection.selectAsTheOnlyOneSelected(model);
	}
}
